==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRenderFunctionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRenderFunctionDescription } from "./WebRenderFunctionDescription";
/**
 * @hidden
 */
export let WebRenderFunctionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRenderFunctionDescriptionMetadata extends Base {
        static b(a) {
            if (WebRenderFunctionDescriptionMetadata.a == null) {
                WebRenderFunctionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRenderFunctionDescriptionMetadata.c(WebRenderFunctionDescriptionMetadata.a);
            }
            if (a.j(WebRenderFunctionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRenderFunctionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RenderFunction");
        }
        static d(a) {
            WebRenderFunctionDescriptionMetadata.b(a);
            a.aa("WebRenderFunction", () => new WebRenderFunctionDescription());
            a.z("WebRenderFunction", WebRenderFunctionDescriptionMetadata.a);
        }
    }
    WebRenderFunctionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRenderFunctionDescriptionMetadata, 'WebRenderFunctionDescriptionMetadata');
    WebRenderFunctionDescriptionMetadata.a = null;
    return WebRenderFunctionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRenderFunctionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRenderFunctionDescription } from "./WebRenderFunctionDescription";
/**
 * @hidden
 */
export let WebRenderFunctionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRenderFunctionDescriptionMetadata extends Base {
        static b(a) {
            if (WebRenderFunctionDescriptionMetadata.a == null) {
                WebRenderFunctionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRenderFunctionDescriptionMetadata.c(WebRenderFunctionDescriptionMetadata.a);
            }
            if (a.k(WebRenderFunctionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRenderFunctionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RenderFunction");
        }
        static d(a) {
            WebRenderFunctionDescriptionMetadata.b(a);
            a.ac("WebRenderFunction", () => new WebRenderFunctionDescription());
            a.ab("WebRenderFunction", WebRenderFunctionDescriptionMetadata.a);
        }
    }
    WebRenderFunctionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRenderFunctionDescriptionMetadata, 'WebRenderFunctionDescriptionMetadata');
    WebRenderFunctionDescriptionMetadata.a = null;
    return WebRenderFunctionDescriptionMetadata;
})();
